@@ -1,3 +1,7 @@
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
+
 #include "dtkcore_global.h"
 #include <QDebug>
 #include <QFileInfo>
@@ -23,7 +27,7 @@ void doubleLoadCheck()
 
         QFileInfo info(maps.value(5));
         const QString &infoAbPath = info.absoluteFilePath();
-        if (modulePath == infoAbPath || !info.fileName().contains("dtkcore"))
+        if (modulePath == infoAbPath || !info.fileName().contains("dtkcore") || info.fileName().contains("dtkcore.so.2"))
             continue;
 
         if (modulePath.isEmpty()) {
@@ -50,5 +54,8 @@ int dtkVersion()
 
 const char *dtkVersionString()
 {
-    return DTK_VERSION_STR;
+#ifdef QT_DEBUG
+    qWarning() << "Use DTK_VERSION_STR instead.";
+#endif
+    return "";//DTK_VERSION_STR;
 }
